# -*- coding: utf-8 -*-
from collections import OrderedDict
import yaml

class literal(str): pass

def literal_presenter(dumper, data):
    return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
yaml.add_representer(literal, literal_presenter)

def ordered_dict_presenter(dumper, data):
    return dumper.represent_dict(data.items())
yaml.add_representer(OrderedDict, ordered_dict_presenter)

class MyDumper(yaml.Dumper):
    def ignore_aliases(self, _data):
        return True
    def increase_indent(self, flow=False, indentless=False):
        return super(MyDumper, self).increase_indent(flow, False)

def dump_humanised(data):
    return yaml.dump(data, allow_unicode=True, default_flow_style=False, canonical=False, Dumper=MyDumper)



# -*- coding: utf-8 -*-
from __future__ import print_function
import sys

def warning(objs):
    print("WARNING: ", objs, file=sys.stdout)
def myexit(objs):
    print("EXITING: ", objs, file=sys.stderr)
    sys.exit(1)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from __future__ import print_function
import sys
import os
import argparse
from itunesfslib import converter
from itunesfslib import helpers


def main():
    parser = argparse.ArgumentParser(
        description='Generates a .yamp configuration file from the assets of a folder',
        epilog="Author: Petros Douvantzis @ Evil Window Dod")
    parser.add_argument('i', metavar='input', help='Relative path to the input folder')
    parser.add_argument('-out', metavar='output', help='Relative path to the output folder')

    #sys.argv = [sys.argv[0]] + '../Horizon -out la'.split(" ")#overide input from command line
    try:
        args = parser.parse_args()
    except:
        print("****************")
        parser.print_help()
        print("****************")
        sys.exit(1)   

    inputpath = os.path.normpath(args.i)
    if not args.out:
        outputpath = None
    else:
        outputpath = os.path.normpath(args.out)
        if inputpath == outputpath:
            helpers.myexit('Input path can not be the same as output path')

    converter.convert(inputpath, outputpath)

if __name__ == '__main__':
    main()

